Documentation
¶
Index ¶
- func ExpandAdventures(client Client, adventure *Adventure, p progressor) error
- func GenerateCoverPrompts(client Client, adventure *Adventure) error
- func GenerateCoversFromPrompts(client ImageClient, adventure *Adventure, path string, progress progressor) error
- func GenerateIllustrationPrompts(client Client, adventure *Adventure) error
- func GenerateIllustrationsFromPrompts(client ImageClient, adventure *Adventure, path string, progress progressor) error
- func GenerateOnePageDungeons(client Client, adventure *Adventure) error
- func GetCopyrightRemovalPrompt() string
- func GetExpandedAdventurePrompt(settingDetails string) string
- func GetIllustrationPrompt() string
- func GetOnePageDungeonPrompt(settingDetails string) string
- func RemoveCopyrightedMaterial(client Client, adventure *Adventure) error
- func SaveToFiles(adventure *Adventure, outputDir string) error
- type Adventure
- type ClaudeClient
- type ClaudeRequest
- type ClaudeResponse
- type Client
- type Config
- type Episode
- type HordeClient
- type IllustrationPrompt
- type ImageClient
- type LLMClient
- type LocalClient
- type Message
- type SDWebUIRequest
- type SDWebUIResponse
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ExpandAdventures ¶
func GenerateCoverPrompts ¶
func GenerateCoversFromPrompts ¶
func GenerateCoversFromPrompts(client ImageClient, adventure *Adventure, path string, progress progressor) error
func GenerateIllustrationsFromPrompts ¶
func GenerateIllustrationsFromPrompts(client ImageClient, adventure *Adventure, path string, progress progressor) error
func GenerateOnePageDungeons ¶
func GetCopyrightRemovalPrompt ¶
func GetCopyrightRemovalPrompt() string
func GetIllustrationPrompt ¶
func GetIllustrationPrompt() string
func GetOnePageDungeonPrompt ¶
func SaveToFiles ¶
Types ¶
type Adventure ¶
type Adventure struct {
Title string
Episodes []Episode
TableOfContents string
OriginalPrompt string
Covers []IllustrationPrompt
Setting string "PROMPT.md"
Style string "STYLE.md"
}
Adventure represents the complete story structure
type ClaudeClient ¶
func NewClaudeClient ¶
func NewClaudeClient(apiKey string) *ClaudeClient
func (*ClaudeClient) SendMessage ¶
func (c *ClaudeClient) SendMessage(systemPrompt, userPrompt string) (string, error)
type ClaudeRequest ¶
ClaudeRequest represents the API request structure
type ClaudeResponse ¶
type ClaudeResponse struct {
Content string `json:"content"`
}
ClaudeResponse represents the API response structure
type Episode ¶
type Episode struct {
Title string
Summary string
Tagline string
Characters []string
Location string
OnePageDungeon string
FullAdventure string
Illustrations []IllustrationPrompt
}
Episode represents a single adventure episode
type HordeClient ¶
func NewHordeClient ¶
func NewHordeClient() *HordeClient
func (*HordeClient) ImageGenerate ¶
type IllustrationPrompt ¶
IllustrationPrompt represents a Stable Diffusion prompt
type ImageClient ¶
type LLMClient ¶
type LLMClient struct {
// client *anthropic.Client
http.Client
// contains filtered or unexported fields
}
func NewLLMClient ¶
type SDWebUIRequest ¶
type SDWebUIRequest struct {
Prompt string `json:"prompt"`
NegativePrompt string `json:"negative_prompt,omitempty"`
Steps int `json:"steps"`
Width int `json:"width"`
Height int `json:"height"`
CFGScale float64 `json:"cfg_scale,omitempty"`
BatchSize int `json:"batch_size,omitempty"`
OverrideSettings map[string]interface{} `json:"override_settings,omitempty"`
}
SDWebUIRequest represents the request structure for the Stable Diffusion WebUI API SDWebUIRequest represents the request structure for the Stable Diffusion WebUI API
type SDWebUIResponse ¶
type SDWebUIResponse struct {
Images []string `json:"images"`
Info string `json:"info"`
Error string `json:"error,omitempty"`
}
SDWebUIResponse represents the response structure from the Stable Diffusion WebUI API
Click to show internal directories.
Click to hide internal directories.